/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function __spreadArrays() {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
}

var buildRegexp = function (dictionary) {
    var content = dictionary.words
        .map(function (word) {
        // i.e. replace 'o' with '(o|0)'
        if (!dictionary.symbolAlternatives)
            return word;
        Object.entries(dictionary.symbolAlternatives).forEach(function (_a) {
            var char = _a[0], replaces = _a[1];
            word = word.replace(new RegExp("" + char, 'gmi'), "(" + replaces.concat(char).join('|') + ")");
        });
        return word;
    })
        .join('|');
    return new RegExp("(\\W+|^)(" + content + ")(\\W+|$)", 'gmi');
};
var checkWord = function (word, dictionary) { var _a; return ((_a = dictionary.regexp) === null || _a === void 0 ? void 0 : _a.test(word)) || false; }; // eslint-disable-line prettier/prettier
var getDefaultDictionary = function () { return ({
    name: 'default',
    words: [],
    regexp: null,
    symbolAlternatives: {
        a: ['4', 'à'],
        e: ['3', '&', '€', 'é', 'è'],
        i: ['1', 'ì', '\\|'],
        o: ['0', 'ò'],
        b: ['8'],
        s: ['\\$'],
        t: ['7', '\\+'],
    },
}); };
var getReplacer = function (replacer, replaceByWord) {
    if (replacer instanceof Function) {
        return replacer;
    }
    return replaceByWord
        ? function () { return replacer; }
        : function (word) { return replacer.repeat(word.length); };
};
var defaultConfig = {
    replaceByWord: false,
    replacer: '*',
};
var DEF_DICT_NAME = 'default';
var ProfanityFactory = function (config) {
    if (config === void 0) { config = defaultConfig; }
    var _a = __assign(__assign({}, defaultConfig), config), dictionary = _a.dictionary, replaceByWord = _a.replaceByWord, replacer = _a.replacer;
    var dictionaries = new Map();
    if (dictionary) {
        dictionaries.set(dictionary.name || DEF_DICT_NAME, dictionary);
    }
    var getOrCreateDictionary = function (key) {
        if (dictionaries.has(key)) {
            return dictionaries.get(key);
        }
        var dict = getDefaultDictionary();
        dictionaries.set(dict.name, dict);
        return dict;
    };
    return {
        addWords: function (words, dictionaryName) {
            if (dictionaryName === void 0) { dictionaryName = DEF_DICT_NAME; }
            var dict = getOrCreateDictionary(dictionaryName);
            dict.words = __spreadArrays(dict.words, words);
            dict.regexp = buildRegexp(dict);
        },
        removeWords: function (words, dictionaryName) {
            if (dictionaryName === void 0) { dictionaryName = DEF_DICT_NAME; }
            var dict = getOrCreateDictionary(dictionaryName);
            dict.words = dict.words.filter(function (w) { return words.indexOf(w) === -1; });
            dict.regexp = buildRegexp(dict);
        },
        check: function (text, dictionaryName) {
            if (dictionaryName === void 0) { dictionaryName = DEF_DICT_NAME; }
            var dict = getOrCreateDictionary(dictionaryName);
            var words = text.split(' ');
            var found = false;
            var count = 0;
            while (found === false && count < words.length) {
                found = checkWord(words[count], dict);
                count += 1;
            }
            return found;
        },
        sanitize: function (text, dictionaryName, override) {
            if (dictionaryName === void 0) { dictionaryName = DEF_DICT_NAME; }
            if (override === void 0) { override = {}; }
            var words = text.split(' ');
            var dict = getOrCreateDictionary(dictionaryName);
            var replaceFunc = getReplacer(override.replacer || replacer, override.replaceByWord !== undefined ? override.replaceByWord : replaceByWord);
            return words
                .map(function (word) { return (checkWord(word, dict) ? replaceFunc(word) : word); })
                .join(' ');
        },
        addDictionary: function (dictionary) {
            if (dictionaries.has(dictionary.name)) {
                throw new Error("Dictionary \"" + dictionary.name + "\" already exists");
            }
            dictionary.regexp = buildRegexp(dictionary);
            dictionaries.set(dictionary.name, dictionary);
        },
        getDictionary: function (name) {
            if (name === void 0) { name = DEF_DICT_NAME; }
            return getOrCreateDictionary(name);
        },
        removeDictionary: function (name) {
            if (name === void 0) { name = DEF_DICT_NAME; }
            return dictionaries.delete(name);
        },
        cleanDictionary: function (name) {
            if (name === void 0) { name = DEF_DICT_NAME; }
            var dict = getOrCreateDictionary(name);
            dict.words = [];
            dict.regexp = buildRegexp(dict);
        },
    };
};

export default ProfanityFactory;
export { ProfanityFactory, getDefaultDictionary };
